@@ -57,8 +57,8 @@ auto.ces <- function(data, models=c("none","simple","full"),
                 cfType=c("MSE","MAE","HAM","MSEh","TMSE","GTMSE","MSCE"),
                 h=10, holdout=FALSE, cumulative=FALSE,
                 intervals=c("none","parametric","semiparametric","nonparametric"), level=0.95,
-                intermittent=c("none","auto","fixed","interval","probability","sba","logistic"),
-                imodel="MNN",
+                occurrence=c("none","auto","fixed","general","odds-ratio","inverse-odds-ratio","direct"),
+                oesmodel="MNN",
                 bounds=c("admissible","none"),
                 silent=c("all","graph","legend","output","none"),
                 xreg=NULL, xregDo=c("use","select"), initialX=NULL,
@@ -145,7 +145,7 @@ auto.ces <- function(data, models=c("none","simple","full"),
                         cfType=cfType,
                         h=h, holdout=holdout,cumulative=cumulative,
                         intervals=intervalsType, level=level,
-                        intermittent=intermittent, imodel=imodel,
+                        occurrence=occurrence, oesmodel=oesmodel,
                         bounds=bounds, silent=silent,
                         xreg=xreg, xregDo=xregDo, initialX=initialX,
                         updateX=updateX, persistenceX=persistenceX, transitionX=transitionX, FI=FI);
@@ -182,7 +182,7 @@ auto.ces <- function(data, models=c("none","simple","full"),
                              cfType=cfType,
                              h=h, holdout=holdout,cumulative=cumulative,
                              intervals=intervalsType, level=level,
-                             intermittent=intermittent, imodel=imodel,
+                             occurrence=occurrence, oesmodel=oesmodel,
                              bounds=bounds, silent=TRUE,
                              xreg=xreg, xregDo=xregDo, initialX=initialX,
                              updateX=updateX, persistenceX=persistenceX, transitionX=transitionX, FI=FI);
