@@ -95,8 +95,8 @@ utils::globalVariables(c("measurementEstimate","transitionEstimate", "C",
 #' \item \code{cumulative} - whether the produced forecast was cumulative or not.
 #' \item \code{actuals} - original data.
 #' \item \code{holdout} - holdout part of the original data.
-#' \item \code{imodel} - model of the class "iss" if intermittent model was estimated.
-#' If the model is non-intermittent, then imodel is \code{NULL}.
+#' \item \code{occurrence} - model of the class "oes" if the occurrence model was estimated.
+#' If the model is non-intermittent, then occurrence is \code{NULL}.
 #' \item \code{xreg} - provided vector or matrix of exogenous variables. If
 #' \code{xregDo="s"}, then this value will contain only selected exogenous variables.
 #' \item \code{updateX} - boolean, defining, if the states of exogenous variables
@@ -164,8 +164,8 @@ gum <- function(data, orders=c(1,1), lags=c(1,frequency(data)), type=c("A","M"),
                 cfType=c("MSE","MAE","HAM","MSEh","TMSE","GTMSE","MSCE"),
                 h=10, holdout=FALSE, cumulative=FALSE,
                 intervals=c("none","parametric","semiparametric","nonparametric"), level=0.95,
-                intermittent=c("none","auto","fixed","interval","probability","sba","logistic"),
-                imodel="MNN",
+                occurrence=c("none","auto","fixed","general","odds-ratio","inverse-odds-ratio","direct"),
+                oesmodel="MNN",
                 bounds=c("restricted","admissible","none"),
                 silent=c("all","graph","legend","output","none"),
                 xreg=NULL, xregDo=c("use","select"), initialX=NULL,
@@ -191,8 +191,8 @@ gum <- function(data, orders=c(1,1), lags=c(1,frequency(data)), type=c("A","M"),
 
         type <- errorType(model);
 
-        if(!is.null(model$imodel)){
-            imodel <- model$imodel;
+        if(!is.null(model$occurrence)){
+            occurrence <- model$occurrence;
         }
         initial <- model$initial;
         persistence <- model$persistence;
@@ -224,6 +224,10 @@ gum <- function(data, orders=c(1,1), lags=c(1,frequency(data)), type=c("A","M"),
 
     orders <- orders[order(lags)];
     lags <- sort(lags);
+    # Remove redundant lags (if present)
+    lags <- lags[!is.na(orders)];
+    # Remove NAs (if lags are longer than orders)
+    orders <- orders[!is.na(orders)];
 
 ##### Set environment for ssInput and make all the checks #####
     environment(ssInput) <- environment();
@@ -318,7 +322,7 @@ CF <- function(C){
                        h, modellags, Etype, Ttype, Stype,
                        multisteps, cfType, normalizer, initialType,
                        matxt, matat, matFX, vecgX, ot,
-                       bounds);
+                       bounds, 0);
 
     if(is.nan(cfRes) | is.na(cfRes)){
         cfRes <- 1e100;
@@ -350,6 +354,10 @@ CreatorGUM <- function(silentText=FALSE,...){
                 }
             }
             if(transitionEstimate){
+                # matFInterim <- diag(nComponents);
+                # matFInterim[upper.tri(matFInterim)] <- 1;
+                # matFInterim[lower.tri(matFInterim)] <- 1;
+                # C <- c(C,c(matFInterim));
                 C <- c(C,rep(1,nComponents^2));
                 if(bounds=="r"){
                     Clb <- c(Clb,rep(0,nComponents^2));
@@ -439,7 +447,7 @@ CreatorGUM <- function(silentText=FALSE,...){
         nParam <- 1;
     }
 
-    ICValues <- ICFunction(nParam=nParam,nParamIntermittent=nParamIntermittent,
+    ICValues <- ICFunction(nParam=nParam,nParamOccurrence=nParamOccurrence,
                            C=C,Etype=Etype);
     ICs <- ICValues$ICs;
     logLik <- ICValues$llikelihood;
@@ -501,8 +509,8 @@ CreatorGUM <- function(silentText=FALSE,...){
 
 # Check number of parameters vs data
     nParamExo <- FXEstimate*length(matFX) + gXEstimate*nrow(vecgX) + initialXEstimate*ncol(matat);
-    nParamIntermittent <- all(intermittent!=c("n","provided"))*1;
-    nParamMax <- nParamMax + nParamExo + nParamIntermittent;
+    nParamOccurrence <- all(occurrence!=c("n","p"))*1;
+    nParamMax <- nParamMax + nParamExo + nParamOccurrence;
 
     if(xregDo=="u"){
         parametersNumber[1,2] <- nParamExo;
@@ -541,8 +549,8 @@ CreatorGUM <- function(silentText=FALSE,...){
         return(es(data,"ANN",initial=initial,cfType=cfType,
                   h=h,holdout=holdout,cumulative=cumulative,
                   intervals=intervals,level=level,
-                  intermittent=intermittent,
-                  imodel=imodel,
+                  occurrence=occurrence,
+                  oesmodel=oesmodel,
                   bounds="u",
                   silent=silent,
                   xreg=xreg,xregDo=xregDo,initialX=initialX,
@@ -550,8 +558,11 @@ CreatorGUM <- function(silentText=FALSE,...){
     }
 
 ##### Preset values of matvt ######
-    slope <- cov(yot[1:min(max(12,dataFreq),obsNonzero),],c(1:min(max(12,dataFreq),obsNonzero)))/var(c(1:min(max(12,dataFreq),obsNonzero)));
-    intercept <- sum(yot[1:min(max(12,dataFreq),obsNonzero),])/min(max(12,dataFreq),obsNonzero) - slope * (sum(c(1:min(max(12,dataFreq),obsNonzero)))/min(max(12,dataFreq),obsNonzero) - 1);
+    slope <- (cov(yot[1:min(max(12,dataFreq),obsNonzero),],c(1:min(max(12,dataFreq),obsNonzero)))/
+                  var(c(1:min(max(12,dataFreq),obsNonzero))));
+    intercept <- (sum(yot[1:min(max(12,dataFreq),obsNonzero),])/min(max(12,dataFreq),obsNonzero) -
+                      slope * (sum(c(1:min(max(12,dataFreq),obsNonzero)))/
+                                   min(max(12,dataFreq),obsNonzero) - 1));
 
     vtvalues <- intercept;
     if((orders %*% lags)>1){
@@ -619,63 +630,46 @@ CreatorGUM <- function(silentText=FALSE,...){
     environment(ssForecaster) <- environment();
     environment(ssFitter) <- environment();
 
-    # If auto intermittent, then estimate model with intermittent="n" first
-    if(any(intermittent==c("a","n"))){
-        intermittentParametersSetter(intermittent="n",ParentEnvironment=environment());
+##### If occurrence=="a", run a loop and select the best one #####
+    if(occurrence=="a"){
+        if(!silentText){
+            cat("Selecting the best occurrence model...\n");
+        }
+        # First produce the auto model
+        intermittentParametersSetter(occurrence="a",ParentEnvironment=environment());
+        intermittentMaker(occurrence="a",ParentEnvironment=environment());
+        intermittentModel <- CreatorGUM(silent=silentText);
+        occurrenceBest <- occurrence;
+        occurrenceModelBest <- occurrenceModel;
+
+        if(!silentText){
+            cat("Comparing it with the best non-intermittent model...\n");
+        }
+        # Then fit the model without the occurrence part
+        occurrence[] <- "n";
+        intermittentParametersSetter(occurrence=occurrence,ParentEnvironment=environment());
+        intermittentMaker(occurrence=occurrence,ParentEnvironment=environment());
+        nonIntermittentModel <- CreatorGUM(silent=silentText);
+
+        # Compare the results and return the best
+        if(nonIntermittentModel$icBest[ic] <= intermittentModel$icBest[ic]){
+            gumValues <- nonIntermittentModel;
+        }
+        # If this is the "auto", then use the selected occurrence to reset the parameters
+        else{
+            gumValues <- intermittentModel;
+            occurrence[] <- occurrenceBest;
+            occurrenceModel <- occurrenceModelBest;
+            intermittentParametersSetter(occurrence=occurrence,ParentEnvironment=environment());
+            intermittentMaker(occurrence=occurrence,ParentEnvironment=environment());
+        }
+        rm(intermittentModel,nonIntermittentModel,occurrenceModelBest);
     }
     else{
-        intermittentParametersSetter(intermittent=intermittent,ParentEnvironment=environment());
-        intermittentMaker(intermittent=intermittent,ParentEnvironment=environment());
-    }
+        intermittentParametersSetter(occurrence=occurrence,ParentEnvironment=environment());
+        intermittentMaker(occurrence=occurrence,ParentEnvironment=environment());
 
-    gumValues <- CreatorGUM(silentText=silentText);
-
-##### If intermittent=="a", run a loop and select the best one #####
-    if(intermittent=="a"){
-        if(!any(cfType==c("MSE","MAE","HAM","MSEh","MAEh","HAMh","MSCE","MACE","CHAM",
-                          "TFL","aTFL","Rounded","TSB","LogisticD","LogisticL"))){
-            warning(paste0("'",cfType,"' is used as cost function instead of 'MSE'. A wrong intermittent model may be selected"),call.=FALSE);
-        }
-        if(!silentText){
-            cat("Selecting appropriate type of intermittency... ");
-        }
-# Prepare stuff for intermittency selection
-        intermittentModelsPool <- c("n","f","i","p","s","l");
-        intermittentCFs <- intermittentICs <- rep(NA,length(intermittentModelsPool));
-        intermittentModelsList <- list(NA);
-        intermittentICs[1] <- gumValues$icBest;
-        intermittentCFs[1] <- gumValues$cfObjective;
-
-        for(i in 2:length(intermittentModelsPool)){
-            intermittentParametersSetter(intermittent=intermittentModelsPool[i],ParentEnvironment=environment());
-            intermittentMaker(intermittent=intermittentModelsPool[i],ParentEnvironment=environment());
-            intermittentModelsList[[i]] <- CreatorGUM(silentText=TRUE);
-            intermittentICs[i] <- intermittentModelsList[[i]]$icBest[ic];
-            intermittentCFs[i] <- intermittentModelsList[[i]]$cfObjective;
-        }
-        intermittentICs[is.nan(intermittentICs) | is.na(intermittentICs)] <- 1e+100;
-        intermittentCFs[is.nan(intermittentCFs) | is.na(intermittentCFs)] <- 1e+100;
-        # In cases when the data is binary, choose between intermittent models only
-        if(any(intermittentCFs==0)){
-            if(all(intermittentCFs[2:length(intermittentModelsPool)]==0)){
-                intermittentICs[1] <- Inf;
-            }
-        }
-        iBest <- which(intermittentICs==min(intermittentICs))[1];
-
-        if(!silentText){
-            cat("Done!\n");
-        }
-        if(iBest!=1){
-            intermittent <- intermittentModelsPool[iBest];
-            gumValues <- intermittentModelsList[[iBest]];
-        }
-        else{
-            intermittent <- "n"
-        }
-
-        intermittentParametersSetter(intermittent=intermittent,ParentEnvironment=environment());
-        intermittentMaker(intermittent=intermittent,ParentEnvironment=environment());
+        gumValues <- CreatorGUM(silentText=silentText);
     }
 
     list2env(gumValues,environment());
@@ -698,7 +692,7 @@ CreatorGUM <- function(silentText=FALSE,...){
         colnames(xregNew)[1] <- "errors";
         colnames(xregNew)[-1] <- xregNames;
         xregNew <- as.data.frame(xregNew);
-        xregResults <- stepwise(xregNew, ic=ic, silent=TRUE, df=nParam+nParamIntermittent-1);
+        xregResults <- stepwise(xregNew, ic=ic, silent=TRUE, df=nParam+nParamOccurrence-1);
         xregNames <- names(coef(xregResults))[-1];
         nExovars <- length(xregNames);
         if(nExovars>0){
@@ -763,7 +757,7 @@ CreatorGUM <- function(silentText=FALSE,...){
         environment(likelihoodFunction) <- environment();
         environment(ICFunction) <- environment();
 
-        ICValues <- ICFunction(nParam=nParam,nParamIntermittent=nParamIntermittent,
+        ICValues <- ICFunction(nParam=nParam,nParamOccurrence=nParamOccurrence,
                                C=C,Etype="M");
         ICs <- ICValues$ICs;
         logLik <- ICValues$llikelihood;
@@ -807,27 +801,9 @@ CreatorGUM <- function(silentText=FALSE,...){
     # Add variance estimation
     parametersNumber[1,1] <- parametersNumber[1,1] + 1;
 
-    # Write down the probabilities from intermittent models
-    pt <- ts(c(as.vector(pt),as.vector(pForecast)),start=dataStart,frequency=dataFreq);
-    # Write down the number of parameters of imodel
-    if(all(intermittent!=c("n","provided")) & !imodelProvided){
-        parametersNumber[1,3] <- imodel$nParam;
-    }
-    # Make nice names for intermittent
-    if(intermittent=="f"){
-        intermittent <- "fixed";
-    }
-    else if(intermittent=="i"){
-        intermittent <- "interval";
-    }
-    else if(intermittent=="p"){
-        intermittent <- "probability";
-    }
-    else if(intermittent=="l"){
-        intermittent <- "logistic";
-    }
-    else if(intermittent=="n"){
-        intermittent <- "none";
+    # Write down the number of parameters of occurrence
+    if(all(occurrence!=c("n","p")) & !occurrenceModelProvided){
+        parametersNumber[1,3] <- nparam(occurrenceModel);
     }
 
 # Make some preparations
@@ -860,10 +836,10 @@ CreatorGUM <- function(silentText=FALSE,...){
     if(holdout){
         yHoldout <- ts(data[(obsInsample+1):obsAll],start=yForecastStart,frequency=frequency(data));
         if(cumulative){
-            errormeasures <- Accuracy(sum(yHoldout),yForecast,h*y);
+            errormeasures <- measures(sum(yHoldout),yForecast,h*y);
         }
         else{
-            errormeasures <- Accuracy(yHoldout,yForecast,y);
+            errormeasures <- measures(yHoldout,yForecast,y);
         }
 
         if(cumulative){
@@ -882,7 +858,7 @@ CreatorGUM <- function(silentText=FALSE,...){
         modelname <- "GUM";
     }
     modelname <- paste0(modelname,"(",paste(orders,"[",lags,"]",collapse=",",sep=""),")");
-    if(all(intermittent!=c("n","none"))){
+    if(all(occurrence!=c("n","none"))){
         modelname <- paste0("i",modelname);
     }
 
@@ -934,7 +910,7 @@ CreatorGUM <- function(silentText=FALSE,...){
                   nParam=parametersNumber,
                   fitted=yFitted,forecast=yForecast,lower=yLower,upper=yUpper,residuals=errors,
                   errors=errors.mat,s2=s2,intervals=intervalsType,level=level,cumulative=cumulative,
-                  actuals=data,holdout=yHoldout,imodel=imodel,
+                  actuals=data,holdout=yHoldout,occurrence=occurrenceModel,
                   xreg=xreg,updateX=updateX,initialX=initialX,persistenceX=persistenceX,transitionX=transitionX,
                   ICs=ICs,logLik=logLik,cf=cfObjective,cfType=cfType,FI=FI,accuracy=errormeasures);
     return(structure(model,class="smooth"));
