@@ -1,115 +1,105 @@
-utils::globalVariables(c("y","obs","imodelProvided","intermittentModel","imodel"))
+utils::globalVariables(c("y","obs","occurrenceModelProvided","occurrenceModel","occurrenceModel"))
 
-intermittentParametersSetter <- function(intermittent="n",...){
-# Function returns basic parameters based on intermittent type
+intermittentParametersSetter <- function(occurrence="n",...){
+# Function returns basic parameters based on occurrence type
     ellipsis <- list(...);
     ParentEnvironment <- ellipsis[['ParentEnvironment']];
 
-    if(all(intermittent!=c("n","provided"))){
+    if(all(occurrence!=c("n","p"))){
         ot <- (y!=0)*1;
         obsNonzero <- sum(ot);
-        # 1 parameter for estimating initial probability
-        nParamIntermittent <- 1;
-        if(intermittent=="p"){
-            # In TSB we only need to estimate smoothing parameter - we do not
-            # estimate any parameters of the Beta distribution.
-            nParamIntermittent <- nParamIntermittent + 1;
+        obsZero <- obsInsample - obsNonzero;
+        # 1 parameter for estimating initial probability. Works for the fixed probability model
+        nParamOccurrence <- 1;
+        if(any(occurrence==c("o","i","d"))){
+            # The minimum number of parameters for these models is 2: level, alpha
+            nParamOccurrence <- nParamOccurrence + 1;
         }
-        else if(any(intermittent==c("i","a"))){
-            # In Croston we also need to estimate smoothing parameter and variance
-            nParamIntermittent <- nParamIntermittent + 2;
+        else if(any(occurrence==c("g","a"))){
+            # In "general" and "auto" the max number is 4
+            nParamOccurrence <- nParamOccurrence + 3;
         }
+        # Demand sizes
         yot <- matrix(y[y!=0],obsNonzero,1);
-        if(!imodelProvided){
-            pt <- matrix(mean(ot),obsInsample,1);
+        if(!occurrenceModelProvided){
+            pFitted <- matrix(mean(ot),obsInsample,1);
             pForecast <- matrix(1,h,1);
         }
         else{
-            if(length(imodel$fitted)>obsInsample){
-                pt <- matrix(imodel$fitted[1:obsInsample],obsInsample,1);
+            if(length(fitted(occurrenceModel))>obsInsample){
+                pFitted <- matrix(fitted(occurrenceModel)[1:obsInsample],obsInsample,1);
             }
-            else if(length(imodel$fitted)<obsInsample){
-                pt <- matrix(c(imodel$fitted,
-                               rep(imodel$fitted[length(imodel$fitted)],obsInsample-length(imodel$fitted))),
+            else if(length(fitted(occurrenceModel))<obsInsample){
+                pFitted <- matrix(c(fitted(occurrenceModel),
+                               rep(fitted(occurrenceModel)[length(fitted(occurrenceModel))],obsInsample-length(fitted(occurrenceModel)))),
                              obsInsample,1);
             }
             else{
-                pt <- matrix(imodel$fitted,obsInsample,1);
+                pFitted <- matrix(fitted(occurrenceModel),obsInsample,1);
             }
 
-            if(length(imodel$forecast)>=h){
-                pForecast <- matrix(imodel$forecast[1:h],h,1);
+            if(length(occurrenceModel$forecast)>=h){
+                pForecast <- matrix(occurrenceModel$forecast[1:h],h,1);
             }
             else{
-                pForecast <- matrix(c(imodel$forecast,
-                                   rep(imodel$forecast[1],h-length(imodel$forecast))),h,1);
+                pForecast <- matrix(c(occurrenceModel$forecast,
+                                   rep(occurrenceModel$forecast[1],h-length(occurrenceModel$forecast))),h,1);
             }
 
-            iprob <- c(pt,pForecast);
         }
     }
     else{
         obsNonzero <- obsInsample;
+        obsZero <- 0;
     }
 
-    if(all(intermittent!=c("n","l","p"))){
-# If number of observations is low, set intermittency to "none"
-        if(obsNonzero < 3){
-            warning(paste0("Not enough non-zero observations for intermittent state space model. We need at least 5.\n",
-                           "Changing intermittent to 'n'."),call.=FALSE);
-            intermittent <- "n";
-        }
-    }
-
-    if(intermittent=="n"){
+    if(occurrence=="n"){
         ot <- rep(1,obsInsample);
         obsNonzero <- obsInsample;
         yot <- y;
-        pt <- matrix(1,obsInsample,1);
+        pFitted <- matrix(1,obsInsample,1);
         pForecast <- matrix(1,h,1);
-        nParamIntermittent <- 0;
+        nParamOccurrence <- 0;
     }
-    iprob <- pt[1];
     ot <- ts(ot,start=dataStart,frequency=dataFreq);
 
     assign("ot",ot,ParentEnvironment);
     assign("obsNonzero",obsNonzero,ParentEnvironment);
+    assign("obsZero",obsZero,ParentEnvironment);
     assign("yot",yot,ParentEnvironment);
-    assign("pt",pt,ParentEnvironment);
+    assign("pFitted",pFitted,ParentEnvironment);
     assign("pForecast",pForecast,ParentEnvironment);
-    assign("nParamIntermittent",nParamIntermittent,ParentEnvironment);
-    assign("iprob",iprob,ParentEnvironment);
+    assign("nParamOccurrence",nParamOccurrence,ParentEnvironment);
 }
 
-intermittentMaker <- function(intermittent="n",...){
-# Function returns all the necessary stuff from intermittent models
+intermittentMaker <- function(occurrence="n",...){
+# Function returns all the necessary stuff from occurrence models
     ellipsis <- list(...);
     ParentEnvironment <- ellipsis[['ParentEnvironment']];
 
-##### If intermittent is not auto, then work normally #####
-    if(all(intermittent!=c("n","provided","a"))){
-        if(!imodelProvided){
-            imodel <- iss(ot, model=intermittentModel, intermittent=intermittent, h=h);
+##### If occurrence is not absent or provided, then work normally #####
+    if(all(occurrence!=c("n","p"))){
+        if(!occurrenceModelProvided){
+            occurrenceModel <- oes(ot, model=occurrenceModel, occurrence=occurrence, h=h);
         }
         else{
-            imodel <- iss(ot, model=intermittentModel, intermittent=intermittent, h=h,
-                          persistence=imodel$persistence, initial=imodel$initial);
+            occurrenceModel <- oes(ot, model=occurrenceModel, h=h);
         }
-        nParamIntermittent <- imodel$nParam;
-        pt[,] <- imodel$fitted;
-        pForecast <- imodel$forecast;
-        iprob <- pForecast[1];
+        nParamOccurrence <- nparam(occurrenceModel);
+        pFitted[,] <- fitted(occurrenceModel);
+        pForecast <- occurrenceModel$forecast;
+        occurrence <- occurrenceModel$occurrence;
     }
     else{
-        imodel <- NULL;
-        nParamIntermittent <- 0;
+        occurrenceModel <- NULL;
+        nParamOccurrence <- 0;
     }
 
-    assign("pt",pt,ParentEnvironment);
+    assign("occurrence",occurrence,ParentEnvironment);
+    assign("pFitted",pFitted,ParentEnvironment);
     assign("pForecast",pForecast,ParentEnvironment);
-    assign("iprob",iprob,ParentEnvironment);
-    assign("nParamIntermittent",nParamIntermittent,ParentEnvironment);
-    assign("imodel",imodel,ParentEnvironment);
+    assign("nParamOccurrence",nParamOccurrence,ParentEnvironment);
+    assign("occurrenceModel",occurrenceModel,ParentEnvironment);
 }
 
 
@@ -164,8 +154,6 @@ intermittentMaker <- function(intermittent="n",...){
 #' }
 #' @seealso \code{\link[forecast]{ets}, \link[forecast]{forecast},
 #' \link[smooth]{es}}
-#' @keywords iss intermittent demand intermittent demand state space model
-#' exponential smoothing forecasting
 #' @examples
 #'
 #'     y <- rpois(100,0.1)
@@ -249,17 +237,17 @@ iss <- function(data, intermittent=c("none","fixed","interval","probability","sb
 #### Fixed probability ####
     if(intermittent=="f"){
         if(!is.null(initial)){
-            pt <- ts(matrix(rep(initial,obsInsample),obsInsample,1), start=start(y), frequency=frequency(y));
+            pFitted <- ts(matrix(rep(initial,obsInsample),obsInsample,1), start=start(y), frequency=frequency(y));
         }
         else{
             initial <- iprob;
-            pt <- ts(matrix(rep(iprob,obsInsample),obsInsample,1), start=start(y), frequency=frequency(y));
+            pFitted <- ts(matrix(rep(iprob,obsInsample),obsInsample,1), start=start(y), frequency=frequency(y));
         }
         names(initial) <- "level";
-        pForecast <- ts(rep(pt[1],h), start=time(y)[obsInsample]+deltat(y), frequency=frequency(y));
+        pForecast <- ts(rep(pFitted[1],h), start=time(y)[obsInsample]+deltat(y), frequency=frequency(y));
         errors <- ts(ot-iprob, start=start(y), frequency=frequency(y));
 
-        output <- list(model=model, fitted=pt, forecast=pForecast, states=pt,
+        output <- list(model=model, fitted=pFitted, forecast=pForecast, states=pFitted,
                        variance=pForecast*(1-pForecast), logLik=NA, nParam=1,
                        residuals=errors, actuals=otAll,
                        persistence=NULL, initial=initial, initialSeason=NULL);
@@ -286,17 +274,17 @@ iss <- function(data, intermittent=c("none","fixed","interval","probability","sb
                            persistence=persistence,initial=initial,
                            ic=ic,xreg=xreg,initialSeason=initialSeason);
 
-        pt <- rep((crostonModel$fitted),zeroes);
-        if(any(pt<1)){
-            pt[pt<1] <- 1;
+        pFitted <- rep((crostonModel$fitted),zeroes);
+        if(any(pFitted<1)){
+            pFitted[pFitted<1] <- 1;
         }
-        tailNumber <- obsInsample - length(pt);
+        tailNumber <- obsInsample - length(pFitted);
         if(tailNumber>0){
             pForecast <- crostonModel$forecast[1:tailNumber];
             if(any(pForecast<1)){
                 pForecast[pForecast<1] <- 1;
             }
-            pt <- c(pt,pForecast);
+            pFitted <- c(pFitted,pForecast);
         }
         pForecast <- crostonModel$forecast[(tailNumber+1):newh];
         if(any(pForecast<1)){
@@ -304,19 +292,19 @@ iss <- function(data, intermittent=c("none","fixed","interval","probability","sb
         }
 
         if(sbaCorrection){
-            pt <- ts((1-sum(crostonModel$persistence)/2)/pt,start=start(y),frequency=frequency(y));
+            pFitted <- ts((1-sum(crostonModel$persistence)/2)/pFitted,start=start(y),frequency=frequency(y));
             pForecast <- ts((1-sum(crostonModel$persistence)/2)/pForecast, start=time(y)[obsInsample]+deltat(y),frequency=frequency(y));
             states <- 1/crostonModel$states;
             intermittent <- "s";
         }
         else{
-            pt <- ts(1/pt,start=start(y),frequency=frequency(y));
+            pFitted <- ts(1/pFitted,start=start(y),frequency=frequency(y));
             pForecast <- ts(1/pForecast, start=time(y)[obsInsample]+deltat(y),frequency=frequency(y));
             states <- 1/crostonModel$states;
         }
 
-        output <- list(model=model, fitted=pt, forecast=pForecast, states=states,
-                       variance=pForecast*(1-pForecast), logLik=NA, nParam=nParam(crostonModel),
+        output <- list(model=model, fitted=pFitted, forecast=pForecast, states=states,
+                       variance=pForecast*(1-pForecast), logLik=NA, nParam=nparam(crostonModel),
                        residuals=crostonModel$residuals, actuals=otAll,
                        persistence=crostonModel$persistence, initial=crostonModel$initial,
                        initialSeason=crostonModel$initialSeason);
@@ -344,7 +332,7 @@ iss <- function(data, intermittent=c("none","fixed","interval","probability","sb
         tsbModel$fitted <- (tsbModel$fitted - kappa) / (1 - 2*kappa);
         tsbModel$forecast <- (tsbModel$forecast - kappa) / (1 - 2*kappa);
 
-        # If bt>1, then at = 0 and pt = bt / (at + bt) = 1
+        # If bt>1, then at = 0 and pFitted = bt / (at + bt) = 1
         if(any(tsbModel$fitted>1)){
             tsbModel$fitted[tsbModel$fitted>1] <- 1;
         }
@@ -352,7 +340,7 @@ iss <- function(data, intermittent=c("none","fixed","interval","probability","sb
             tsbModel$forecast[tsbModel$forecast>1] <- 1;
         }
 
-        # If at>1, then bt = 0 and pt = bt / (at + bt) = 0
+        # If at>1, then bt = 0 and pFitted = bt / (at + bt) = 0
         if(any(tsbModel$fitted<0)){
             tsbModel$fitted[tsbModel$fitted<0] <- 0;
         }
@@ -361,7 +349,7 @@ iss <- function(data, intermittent=c("none","fixed","interval","probability","sb
         }
 
         output <- list(model=model, fitted=tsbModel$fitted, forecast=tsbModel$forecast, states=tsbModel$states,
-                       variance=tsbModel$forecast*(1-tsbModel$forecast), logLik=NA, nParam=nParam(tsbModel)-1,
+                       variance=tsbModel$forecast*(1-tsbModel$forecast), logLik=NA, nParam=nparam(tsbModel)-1,
                        residuals=tsbModel$residuals, actuals=otAll,
                        persistence=tsbModel$persistence, initial=tsbModel$initial,
                        initialSeason=tsbModel$initialSeason);
@@ -425,31 +413,31 @@ iss <- function(data, intermittent=c("none","fixed","interval","probability","sb
         }
 
         output <- list(model=modelType(logisticModel), fitted=logisticModel$fitted, forecast=logisticModel$forecast, states=logisticModel$states,
-                       variance=logisticModel$forecast*(1-logisticModel$forecast), logLik=NA, nParam=nParam(logisticModel),
+                       variance=logisticModel$forecast*(1-logisticModel$forecast), logLik=NA, nParam=nparam(logisticModel),
                        residuals=logisticModel$residuals, actuals=otAll,
                        persistence=logisticModel$persistence, initial=logisticModel$initial,
                        initialSeason=logisticModel$initialSeason);
     }
 #### None ####
     else{
-        pt <- ts(y,start=start(y),frequency=frequency(y));
+        pFitted <- ts(y,start=start(y),frequency=frequency(y));
         pForecast <- ts(rep(y[obsInsample],h), start=time(y)[obsInsample]+deltat(y),frequency=frequency(y));
         errors <- ts(rep(0,obsInsample), start=start(y), frequency=frequency(y));
-        output <- list(model=NULL, fitted=pt, forecast=pForecast, states=pt,
+        output <- list(model=NULL, fitted=pFitted, forecast=pForecast, states=pFitted,
                        variance=rep(0,h), logLik=NA, nParam=0,
-                       residuals=errors, actuals=pt,
+                       residuals=errors, actuals=pFitted,
                        persistence=NULL, initial=NULL, initialSeason=NULL);
     }
     output$intermittent <- intermittent;
-    pt <- output$fitted;
-    if(any(c(1-pt[ot==0]==0,pt[ot==1]==0))){
+    pFitted <- output$fitted;
+    if(any(c(1-pFitted[ot==0]==0,pFitted[ot==1]==0))){
         # return(-Inf);
-        ptNew <- pt[(pt!=0) & (pt!=1)];
-        otNew <- ot[(pt!=0) & (pt!=1)];
+        ptNew <- pFitted[(pFitted!=0) & (pFitted!=1)];
+        otNew <- ot[(pFitted!=0) & (pFitted!=1)];
         output$logLik <- sum(log(ptNew[otNew==1])) + sum(log(1-ptNew[otNew==0]));
     }
     else{
-        output$logLik <- (sum(log(pt[ot!=0])) + sum(log(1-pt[ot==0])));
+        output$logLik <- (sum(log(pFitted[ot!=0])) + sum(log(1-pFitted[ot==0])));
     }
     return(structure(output,class="iss"));
 }
