@@ -48,7 +48,7 @@
 #' columns, time is in rows.
 #' \item \code{residuals} - Error terms used in the simulation. Either vector or matrix,
 #' depending on \code{nsim}.
-#' \item \code{occurrences} - Values of occurrence variable. Once again, can be either
+#' \item \code{occurrence} - Values of occurrence variable. Once again, can be either
 #' a vector or a matrix...
 #' \item \code{logLik} - Log-likelihood of the constructed model.
 #' }
@@ -388,6 +388,6 @@ sim.gum <- function(orders=c(1), lags=c(1),
     model <- list(model=modelname, measurement=measurementValue, transition=transitionValue,
                   persistence=persistenceValue,initial=matInitialValue,
                   data=matyt, states=arrvt, residuals=materrors,
-                  occurrences=matot, logLik=veclikelihood);
+                  occurrence=matot, logLik=veclikelihood);
     return(structure(model,class="smooth.sim"));
 }
