@@ -56,8 +56,8 @@
 #' \item \code{cumulative} - whether the produced forecast was cumulative or not.
 #' \item \code{actuals} - original data.
 #' \item \code{holdout} - holdout part of the original data.
-#' \item \code{imodel} - model of the class "iss" if intermittent model was estimated.
-#' If the model is non-intermittent, then imodel is \code{NULL}.
+#' \item \code{occurrence} - model of the class "oes" if the occurrence model was estimated.
+#' If the model is non-intermittent, then occurrence is \code{NULL}.
 #' \item \code{xreg} - provided vector or matrix of exogenous variables. If \code{xregDo="s"},
 #' then this value will contain only selected exogenous variables.
 #' \item \code{updateX} - boolean, defining, if the states of exogenous variables were
@@ -96,8 +96,8 @@ smoothCombine <- function(data, models=NULL,
                           h=10, holdout=FALSE, cumulative=FALSE,
                           intervals=c("none","parametric","semiparametric","nonparametric"), level=0.95,
                           bins=200, intervalsCombine=c("quantile","probability"),
-                          intermittent=c("none","auto","fixed","interval","probability","sba","logistic"),
-                          imodel="MNN",
+                          occurrence=c("none","auto","fixed","general","odds-ratio","inverse-odds-ratio","probability"),
+                          oesmodel="MNN",
                           bounds=c("admissible","none"),
                           silent=c("all","graph","legend","output","none"),
                           xreg=NULL, xregDo=c("use","select"), initialX=NULL,
@@ -157,32 +157,32 @@ smoothCombine <- function(data, models=NULL,
             cat("ES");
         }
         esModel <- es(data,initial=initial,ic=ic,cfType=cfType,h=h,holdout=holdout,
-                      cumulative=cumulative,intervals="n",intermittent=intermittent,
-                      imodel=imodel,bounds=bounds,silent=TRUE,
+                      cumulative=cumulative,intervals="n",occurrence=occurrence,
+                      oesmodel=oesmodel,bounds=bounds,silent=TRUE,
                       xreg=xreg,xregDo=xregDo,updateX=updateX,
                       initialX=initialX,persistenceX=persistenceX,transitionX=transitionX);
         if(!silentText){
             cat(", CES");
         }
         cesModel <- auto.ces(data,initial=initial,ic=ic,cfType=cfType,h=h,holdout=holdout,
-                             cumulative=cumulative,intervals="n",intermittent=intermittent,
-                             imodel=imodel,bounds=bounds,silent=TRUE,
+                             cumulative=cumulative,intervals="n",occurrence=occurrence,
+                             oesmodel=oesmodel,bounds=bounds,silent=TRUE,
                              xreg=xreg,xregDo=xregDo,updateX=updateX,
                              initialX=initialX,persistenceX=persistenceX,transitionX=transitionX);
         if(!silentText){
             cat(", SSARIMA");
         }
         ssarimaModel <- auto.ssarima(data,initial=initial,ic=ic,cfType=cfType,h=h,holdout=holdout,
-                                     cumulative=cumulative,intervals="n",intermittent=intermittent,
-                                     imodel=imodel,bounds=bounds,silent=TRUE,
+                                     cumulative=cumulative,intervals="n",occurrence=occurrence,
+                                     oesmodel=oesmodel,bounds=bounds,silent=TRUE,
                                      xreg=xreg,xregDo=xregDo,updateX=updateX,
                                      initialX=initialX,persistenceX=persistenceX,transitionX=transitionX);
         if(!silentText){
             cat(", GUM");
         }
         gumModel <- auto.gum(data,initial=initial,ic=ic,cfType=cfType,h=h,holdout=holdout,
-                             cumulative=cumulative,intervals="n",intermittent=intermittent,
-                             imodel=imodel,bounds=bounds,silent=TRUE,
+                             cumulative=cumulative,intervals="n",occurrence=occurrence,
+                             oesmodel=oesmodel,bounds=bounds,silent=TRUE,
                              xreg=xreg,xregDo=xregDo,updateX=updateX,
                              initialX=initialX,persistenceX=persistenceX,transitionX=transitionX);
         if(!silentText){
@@ -326,10 +326,10 @@ smoothCombine <- function(data, models=NULL,
     ##### Now let's deal with holdout #####
     if(holdout){
         if(cumulative){
-            errormeasures <- Accuracy(sum(yHoldout),yForecast,h*y);
+            errormeasures <- measures(sum(yHoldout),yForecast,h*y);
         }
         else{
-            errormeasures <- Accuracy(yHoldout,yForecast,y);
+            errormeasures <- measures(yHoldout,yForecast,y);
         }
 
         if(cumulative){
