@@ -7,6 +7,9 @@ utils::globalVariables(c("normalizer","constantValue","constantRequired","consta
 #' Function constructs State Space ARIMA, estimating AR, MA terms and initial
 #' states.
 #'
+#' The model, implemented in this function, is discussed in Svetunkov & Boylan
+#' (2019).
+#'
 #' The basic ARIMA(p,d,q) used in the function has the following form:
 #'
 #' \eqn{(1 - B)^d (1 - a_1 B - a_2 B^2 - ... - a_p B^p) y_[t] = (1 + b_1 B +
@@ -37,7 +40,10 @@ utils::globalVariables(c("normalizer","constantValue","constantRequired","consta
 #' Due to the flexibility of the model, multiple seasonalities can be used. For
 #' example, something crazy like this can be constructed:
 #' SARIMA(1,1,1)(0,1,1)[24](2,0,1)[24*7](0,0,1)[24*30], but the estimation may
-#' take some finite time...
+#' take some finite time... If you plan estimating a model with more than one
+#' seasonality, it is recommended to consider doing it using \link[smooth]{msarima}.
+#'
+#' The model selection for SSARIMA is done by the \link[smooth]{auto.ssarima} function.
 #'
 #' @template ssBasicParam
 #' @template ssAdvancedParam
@@ -47,6 +53,7 @@ utils::globalVariables(c("normalizer","constantValue","constantRequired","consta
 #'
 #' @template ssIntervalsRef
 #' @template ssGeneralRef
+#' @template ssARIMARef
 #'
 #' @param orders List of orders, containing vector variables \code{ar},
 #' \code{i} and \code{ma}. Example:
@@ -117,8 +124,8 @@ utils::globalVariables(c("normalizer","constantValue","constantRequired","consta
 #' \item \code{cumulative} - whether the produced forecast was cumulative or not.
 #' \item \code{actuals} - the original data.
 #' \item \code{holdout} - the holdout part of the original data.
-#' \item \code{imodel} - model of the class "iss" if intermittent model was estimated.
-#' If the model is non-intermittent, then imodel is \code{NULL}.
+#' \item \code{occurrence} - model of the class "oes" if the occurrence model was estimated.
+#' If the model is non-intermittent, then occurrence is \code{NULL}.
 #' \item \code{xreg} - provided vector or matrix of exogenous variables. If
 #' \code{xregDo="s"}, then this value will contain only selected exogenous
 #' variables.
@@ -144,7 +151,8 @@ utils::globalVariables(c("normalizer","constantValue","constantRequired","consta
 #' }
 #'
 #' @seealso \code{\link[smooth]{auto.ssarima}, \link[smooth]{orders},
-#' \link[smooth]{lags}, \link[smooth]{sim.ssarima}, \link[forecast]{auto.arima}}
+#' \link[smooth]{lags}, \link[smooth]{msarima}, \link[smooth]{auto.msarima},
+#' \link[smooth]{sim.ssarima}, \link[forecast]{auto.arima}}
 #'
 #' @examples
 #'
@@ -197,8 +205,8 @@ ssarima <- function(data, orders=list(ar=c(0),i=c(1),ma=c(1)), lags=c(1),
                     cfType=c("MSE","MAE","HAM","MSEh","TMSE","GTMSE","MSCE"),
                     h=10, holdout=FALSE, cumulative=FALSE,
                     intervals=c("none","parametric","semiparametric","nonparametric"), level=0.95,
-                    intermittent=c("none","auto","fixed","interval","probability","sba","logistic"),
-                    imodel="MNN",
+                    occurrence=c("none","auto","fixed","general","odds-ratio","inverse-odds-ratio","direct"),
+                    oesmodel="MNN",
                     bounds=c("admissible","none"),
                     silent=c("all","graph","legend","output","none"),
                     xreg=NULL, xregDo=c("use","select"), initialX=NULL,
@@ -225,8 +233,8 @@ ssarima <- function(data, orders=list(ar=c(0),i=c(1),ma=c(1)), lags=c(1),
 
 # If this is a normal ARIMA, do things
         if(any(unlist(gregexpr("combine",model$model))==-1)){
-            if(!is.null(model$imodel)){
-                imodel <- model$imodel;
+            if(!is.null(model$occurrence)){
+                occurrence <- model$occurrence;
             }
             if(!is.null(model$initial)){
                 initial <- model$initial;
@@ -329,7 +337,7 @@ CF <- function(C){
                            xregEstimate, updateX, FXEstimate, gXEstimate, initialXEstimate,
                            bounds,
                            # The last bit is "ssarimaOld"
-                           TRUE, nonZeroARI, nonZeroMA);
+                           TRUE, nonZeroARI, nonZeroMA, 0);
 
     if(is.nan(cfRes) | is.na(cfRes) | is.infinite(cfRes)){
         cfRes <- 1e+100;
@@ -422,13 +430,13 @@ CreatorSSARIMA <- function(silentText=FALSE,...){
         nParam <- 1;
     }
 
-    ICValues <- ICFunction(nParam=nParam,nParamIntermittent=nParamIntermittent,
+    ICValues <- ICFunction(nParam=nParam,nParamOccurrence=nParamOccurrence,
                            C=C,Etype=Etype);
     ICs <- ICValues$ICs;
-    bestIC <- ICs[ic];
+    icBest <- ICs[ic];
     logLik <- ICValues$llikelihood;
 
-    return(list(cfObjective=cfObjective,C=C,ICs=ICs,bestIC=bestIC,nParam=nParam,logLik=logLik));
+    return(list(cfObjective=cfObjective,C=C,ICs=ICs,icBest=icBest,nParam=nParam,logLik=logLik));
 }
 
     # Prepare lists for the polynomials
@@ -519,8 +527,8 @@ CreatorSSARIMA <- function(silentText=FALSE,...){
 
     # Check number of parameters vs data
     nParamExo <- FXEstimate*length(matFX) + gXEstimate*nrow(vecgX) + initialXEstimate*ncol(matat);
-    nParamIntermittent <- all(intermittent!=c("n","provided"))*1;
-    nParamMax <- nParamMax + nParamExo + nParamIntermittent;
+    nParamOccurrence <- all(occurrence!=c("n","p"))*1;
+    nParamMax <- nParamMax + nParamExo + nParamOccurrence;
 
     if(xregDo=="u"){
         parametersNumber[1,2] <- nParamExo;
@@ -562,8 +570,8 @@ CreatorSSARIMA <- function(silentText=FALSE,...){
                        initial=initial,cfType=cfType,
                        h=h,holdout=holdout,cumulative=cumulative,
                        intervals=intervals,level=level,
-                       intermittent=intermittent,
-                       imodel=imodel,
+                       occurrence=occurrence,
+                       oesmodel=oesmodel,
                        bounds="u",
                        silent=silent,
                        xreg=xreg,xregDo=xregDo,initialX=initialX,
@@ -576,66 +584,46 @@ CreatorSSARIMA <- function(silentText=FALSE,...){
     environment(ssForecaster) <- environment();
     environment(ssFitter) <- environment();
 
-    # If auto intermittent, then estimate model with intermittent="n" first.
-    if(any(intermittent==c("a","n"))){
-        intermittentParametersSetter(intermittent="n",ParentEnvironment=environment());
+##### If occurrence=="a", run a loop and select the best one #####
+    if(occurrence=="a"){
+        if(!silentText){
+            cat("Selecting the best occurrence model...\n");
+        }
+        # First produce the auto model
+        intermittentParametersSetter(occurrence="a",ParentEnvironment=environment());
+        intermittentMaker(occurrence="a",ParentEnvironment=environment());
+        intermittentModel <- CreatorSSARIMA(silent=silentText);
+        occurrenceBest <- occurrence;
+        occurrenceModelBest <- occurrenceModel;
+
+        if(!silentText){
+            cat("Comparing it with the best non-intermittent model...\n");
+        }
+        # Then fit the model without the occurrence part
+        occurrence[] <- "n";
+        intermittentParametersSetter(occurrence=occurrence,ParentEnvironment=environment());
+        intermittentMaker(occurrence=occurrence,ParentEnvironment=environment());
+        nonIntermittentModel <- CreatorSSARIMA(silent=silentText);
+
+        # Compare the results and return the best
+        if(nonIntermittentModel$icBest[ic] <= intermittentModel$icBest[ic]){
+            ssarimaValues <- nonIntermittentModel;
+        }
+        # If this is the "auto", then use the selected occurrence to reset the parameters
+        else{
+            ssarimaValues <- intermittentModel;
+            occurrence[] <- occurrenceBest;
+            occurrenceModel <- occurrenceModelBest;
+            intermittentParametersSetter(occurrence=occurrence,ParentEnvironment=environment());
+            intermittentMaker(occurrence=occurrence,ParentEnvironment=environment());
+        }
+        rm(intermittentModel,nonIntermittentModel,occurrenceModelBest);
     }
     else{
-        intermittentParametersSetter(intermittent=intermittent,ParentEnvironment=environment());
-        intermittentMaker(intermittent=intermittent,ParentEnvironment=environment());
-    }
+        intermittentParametersSetter(occurrence=occurrence,ParentEnvironment=environment());
+        intermittentMaker(occurrence=occurrence,ParentEnvironment=environment());
 
-    ssarimaValues <- CreatorSSARIMA(silentText);
-
-##### If intermittent=="a", run a loop and select the best one #####
-    if(intermittent=="a"){
-        if(!any(cfType==c("MSE","MAE","HAM","MSEh","MAEh","HAMh","MSCE","MACE","CHAM",
-                          "TFL","aTFL","Rounded","TSB","LogisticD","LogisticL"))){
-            warning(paste0("'",cfType,"' is used as cost function instead of 'MSE'. A wrong intermittent model may be selected"),call.=FALSE);
-        }
-        if(!silentText){
-            cat("Selecting appropriate type of intermittency... ");
-        }
-# Prepare stuff for intermittency selection
-        intermittentModelsPool <- c("n","f","i","p","s","l");
-        intermittentCFs <- intermittentICs <- rep(NA,length(intermittentModelsPool));
-        intermittentModelsList <- list(NA);
-        intermittentICs[1] <- ssarimaValues$bestIC[ic];
-        intermittentCFs[1] <- ssarimaValues$cfObjective;
-
-        for(i in 2:length(intermittentModelsPool)){
-            intermittentParametersSetter(intermittent=intermittentModelsPool[i],ParentEnvironment=environment());
-            intermittentMaker(intermittent=intermittentModelsPool[i],ParentEnvironment=environment());
-            intermittentModelsList[[i]] <- CreatorSSARIMA(silentText=TRUE);
-            intermittentICs[i] <- intermittentModelsList[[i]]$bestIC[ic];
-            intermittentCFs[i] <- intermittentModelsList[[i]]$cfObjective;
-            # if(intermittentICs[i]>intermittentICs[i-1]){
-            #     break;
-            # }
-        }
-        intermittentICs[is.nan(intermittentICs) | is.na(intermittentICs)] <- 1e+100;
-        intermittentCFs[is.nan(intermittentCFs) | is.na(intermittentCFs)] <- 1e+100;
-        # In cases when the data is binary, choose between intermittent models only
-        if(any(intermittentCFs==0)){
-            if(all(intermittentCFs[2:length(intermittentModelsPool)]==0)){
-                intermittentICs[1] <- Inf;
-            }
-        }
-        iBest <- which(intermittentICs==min(intermittentICs))[1];
-
-        if(!silentText){
-            cat("Done!\n");
-        }
-        if(iBest!=1){
-            intermittent <- intermittentModelsPool[iBest];
-            ssarimaValues <- intermittentModelsList[[iBest]];
-        }
-        else{
-            intermittent <- "n"
-        }
-
-        intermittentParametersSetter(intermittent=intermittent,ParentEnvironment=environment());
-        intermittentMaker(intermittent=intermittent,ParentEnvironment=environment());
+        ssarimaValues <- CreatorSSARIMA(silent=silentText);
     }
 
     list2env(ssarimaValues,environment());
@@ -666,7 +654,7 @@ CreatorSSARIMA <- function(silentText=FALSE,...){
         colnames(xregNew)[1] <- "errors";
         colnames(xregNew)[-1] <- xregNames;
         xregNew <- as.data.frame(xregNew);
-        xregResults <- stepwise(xregNew, ic=ic, silent=TRUE, df=nParam+nParamIntermittent-1);
+        xregResults <- stepwise(xregNew, ic=ic, silent=TRUE, df=nParam+nParamOccurrence-1);
         xregNames <- names(coef(xregResults))[-1];
         nExovars <- length(xregNames);
         if(nExovars>0){
@@ -769,27 +757,9 @@ CreatorSSARIMA <- function(silentText=FALSE,...){
     # Add variance estimation
     parametersNumber[1,1] <- parametersNumber[1,1] + 1;
 
-    # Write down the probabilities from intermittent models
-    pt <- ts(c(as.vector(pt),as.vector(pForecast)),start=dataStart,frequency=dataFreq);
-    # Write down the number of parameters of imodel
-    if(all(intermittent!=c("n","provided")) & !imodelProvided){
-        parametersNumber[1,3] <- imodel$nParam;
-    }
-    # Make nice names for intermittent
-    if(intermittent=="f"){
-        intermittent <- "fixed";
-    }
-    else if(intermittent=="i"){
-        intermittent <- "interval";
-    }
-    else if(intermittent=="p"){
-        intermittent <- "probability";
-    }
-    else if(intermittent=="l"){
-        intermittent <- "logistic";
-    }
-    else if(intermittent=="n"){
-        intermittent <- "none";
+    # Write down the number of parameters of occurrence model
+    if(all(occurrence!=c("n","p")) & !occurrenceModelProvided){
+        parametersNumber[1,3] <- nparam(occurrenceModel);
     }
 
 # Fill in the rest of matvt
@@ -892,7 +862,7 @@ CreatorSSARIMA <- function(silentText=FALSE,...){
             modelname <- paste0("SARIMA",modelname);
         }
     }
-    if(all(intermittent!=c("n","none"))){
+    if(all(occurrence!=c("n","none"))){
         modelname <- paste0("i",modelname);
     }
 
@@ -946,10 +916,10 @@ CreatorSSARIMA <- function(silentText=FALSE,...){
     if(holdout){
         yHoldout <- ts(data[(obsInsample+1):obsAll],start=yForecastStart,frequency=frequency(data));
         if(cumulative){
-            errormeasures <- Accuracy(sum(yHoldout),yForecast,h*y);
+            errormeasures <- measures(sum(yHoldout),yForecast,h*y);
         }
         else{
-            errormeasures <- Accuracy(yHoldout,yForecast,y);
+            errormeasures <- measures(yHoldout,yForecast,y);
         }
 
         if(cumulative){
@@ -993,7 +963,7 @@ CreatorSSARIMA <- function(silentText=FALSE,...){
                   nParam=parametersNumber,
                   fitted=yFitted,forecast=yForecast,lower=yLower,upper=yUpper,residuals=errors,
                   errors=errors.mat,s2=s2,intervals=intervalsType,level=level,cumulative=cumulative,
-                  actuals=data,holdout=yHoldout,imodel=imodel,
+                  actuals=data,holdout=yHoldout,occurrence=occurrenceModel,
                   xreg=xreg,updateX=updateX,initialX=initialX,persistenceX=persistenceX,transitionX=transitionX,
                   ICs=ICs,logLik=logLik,cf=cfObjective,cfType=cfType,FI=FI,accuracy=errormeasures);
     return(structure(model,class="smooth"));
