@@ -1,16 +1,14 @@
 #' @export
 logLik.vsmooth <- function(object,...){
     obs <- nobs(object);
-    # Division by nSeries gives the df per series, which agrees with Lutkepohl (2005), p.75
-    nParamPerSeries <- nParam(object) / ncol(object$actuals);
+    nParamPerSeries <- nparam(object);
     structure(object$logLik,nobs=obs,df=nParamPerSeries,class="logLik");
 }
 
 #' @export
 logLik.viss <- function(object,...){
     obs <- nobs(object);
-    # Division by nSeries gives the df per series, which agrees with Lutkepohl (2005), p.75
-    nParamPerSeries <- nParam(object) / ncol(object$actuals);
+    nParamPerSeries <- nparam(object);
     structure(object$logLik,nobs=obs,df=nParamPerSeries,class="logLik");
 }
 
@@ -19,7 +17,11 @@ AICc.vsmooth <- function(object, ...){
     llikelihood <- logLik(object);
     llikelihood <- llikelihood[1:length(llikelihood)];
     nSeries <- ncol(object$actuals);
-    nParamAll <- nParam(object) / nSeries;
+    # Remove covariances in the number of parameters
+    nParamAll <- nparam(object) / nSeries - switch(object$cfType,
+                                                   "likelihood" = nSeries*(nSeries+1)/2,
+                                                   "trace" = ,
+                                                   "diagonal" = 1);
 
     obs <- nobs(object);
     IC <- -2*llikelihood + ((2*obs*(nParamAll*nSeries + nSeries*(nSeries+1)/2)) /
@@ -33,7 +35,11 @@ BICc.vsmooth <- function(object, ...){
     llikelihood <- logLik(object);
     llikelihood <- llikelihood[1:length(llikelihood)];
     nSeries <- ncol(object$actuals);
-    nParamAll <- nParam(object) / nSeries;
+    # Remove covariances in the number of parameters
+    nParamAll <- nparam(object) / nSeries - switch(object$cfType,
+                                                   "likelihood" = nSeries*(nSeries+1)/2,
+                                                   "trace" = ,
+                                                   "diagonal" = 1);
 
     obs <- nobs(object);
     IC <- -2*llikelihood + (((nParamAll + nSeries*(nSeries+1)/2) *
@@ -53,7 +59,7 @@ nobs.viss <- function(object, ...){
 }
 
 #' @export
-nParam.viss <- function(object, ...){
+nparam.viss <- function(object, ...){
     nParamReturn <- object$nParam[1,4];
     return(nParamReturn);
 }
